#### Bitimage package

**Creating a pip package from custom library - Bitimages**

The purpose of this project is to create a pip package from previously created python library.

**Author**

Basia Kistowska
